## **Sports Biomechanics**

**[ISSN: 1476-3141 (Print) 1752-6116 (Online) Journal homepage: http://www.tandfonline.com/loi/rspb20](http://www.tandfonline.com/loi/rspb20)**

# **Optimisation of applied loads when using the** **two-point method for assessing the force-velocity** **relationship during vertical jumps**

**Amador García-Ramos, Alejandro Pérez-Castilla & Slobodan Jaric**

**To cite this article:** Amador García-Ramos, Alejandro Pérez-Castilla & Slobodan Jaric (2018):
Optimisation of applied loads when using the two-point method for assessing the force-velocity
[relationship during vertical jumps, Sports Biomechanics, DOI: 10.1080/14763141.2018.1545044](http://www.tandfonline.com/action/showCitFormats?doi=10.1080/14763141.2018.1545044)

**To link to this article:** [https://doi.org/10.1080/14763141.2018.1545044](https://doi.org/10.1080/14763141.2018.1545044)

Published online: 12 Dec 2018.

[Submit your article to this journal](http://www.tandfonline.com/action/authorSubmission?journalCode=rspb20&show=instructions)

Article views: 69

[View Crossmark data](http://crossmark.crossref.org/dialog/?doi=10.1080/14763141.2018.1545044&domain=pdf&date_stamp=2018-12-12)

Full Terms & Conditions of access and use can be found at
[http://www.tandfonline.com/action/journalInformation?journalCode=rspb20](http://www.tandfonline.com/action/journalInformation?journalCode=rspb20)

SPORTS BIOMECHANICS

<https://doi.org/10.1080/14763141.2018.1545044>

ARTICLE

### Optimisation of applied loads when using the two-point method for assessing the force-velocity relationship during vertical jumps

Amador García-Ramos a,b, Alejandro Pérez-Castilla a and Slobodan Jaric c

aDepartment of Physical Education and Sport, Faculty of Sport Sciences, University of Granada, Granada,
Spain; \[b\] Department of Sports Sciences and Physical Conditioning, Faculty of Education, CIEDE, Catholic
University of the Most Holy Concepción, Concepción, Chile; \[c\] Department of Kinesiology and Applied
Physiology & Biomechanics and Movement Science Graduate Program, University of Delaware, Newark,
DE, USA

ABSTRACT
This study aimed to compare the reliability and validity of the forcevelocity (F-V) relationship parameters obtained from two-point methods differing in the distance between experimental points, and to
evaluate the acute change in unloaded jump height after a vertical
jump testing procedure based on multiple loads. Totally, 18 men
randomly performed two sessions of the squat jump (SJ) and two
sessions of the countermovement jump (CMJ) exercises against five
external loads (17, 30, 45, 60 and 75 kg). The unloaded jump height
was evaluated before and after each testing procedure. Five twopoint methods (0–17, 0–30, 0–45, 0–60 and 0–75 kg) and the multiple-point method (0–17–30–45–60–75 kg) were used to model the

–
F-V relationship. The most distant two-point method (0 75 kg)
revealed a comparable reliability (CV\< 12.1%; ICC> 0.72) and high
concurrent validity (r > 0.91) with respect to the multiple-point
method (CV\< 10.9%; ICC> 0.72). The reliability and validity of the twopoint methods decreased with the proximity of the applied loads.
Unloaded jump height was significantly reduced after both testing
procedures (p \< 0.05). These results support the two-point method
based on distant loads as a quick and less prone to fatigue procedure
for testing the F-V relationship through vertical jumps.

Introduction

ARTICLE HISTORY
Received 12 July 2018
Accepted 29 October 2018

KEYWORDS
Reliability; concurrent
validity; squat jump;
countermovement jump;
lower-body muscular
function

Vertical jumps are one of the multi-joint tasks most commonly used for training and
testing lower-body muscles in different populations (Baker, 1996; Hansen, Cronin,
Pickering, & Newton, 2011; Moir, Button, Glaister, & Stone, 2004; Runge, Rittweger,
Russo, Schiessl, & Felsenberg, 2004). The squat jump (SJ) and countermovement jump
(CMJ) are the two jumping modalities that have received the most scientific attention
(Bobbert, Gerritsen, Litjens, & Van Soest, 1996; Markovic, Dizdar, Jukic, & Cardinale,
2004). The standard vertical jump testing procedure consists of recording force, velocity
and power outputs independently for each applied load (Cormie, McBride, &
McCaulley, 2008; McBride, Haines, & Kirby, 2011; Moir et al., 2004). However, it is

CONTACT Amador García-Ramos <amagr@ugr.es>

© 2018 Informa UK Limited, trading as Taylor & Francis Group

2 A. GARCÍA-RAMOS ET AL.

important to note that this testing procedure does not allow discernment of the
maximal force, velocity and power-producing capacities (Jaric, 2016). Namely, for
a given individual, the mechanical outputs collected under individual loads are interdependent, and the recorded values are typically lower than the theoretical maximal
capacities to produce force (F0), velocity (V0) and power (Pmax). Therefore, the forcevelocity (F-V) relationship should be modelled to obtain more comprehensive information regarding the lower-body function during vertical jumps tests (Jaric, 2015).

The routine vertical jump testing procedure used for modelling the F-V relationship
over recent years has consisted of the assessment of force and velocity outputs under
multiple loading conditions (between 5 and 9 loads) (Cuk et al., 2014; Feeney,
Stanhope, Kaminski, Machi, & Jaric, 2016; García-Ramos, Feriche, Pérez-Castilla,
Padial, & Jaric, 2017; Giroux, Rabita, Chollet, & Guilhem, 2015). Thereafter, a linear
regression model is typically applied to the recorded force and velocity data to determine the F-V relationship parameters (F0, V0, Pmax and F-V slope) (Iglesias-Soler,
Farinas, Mayo, Santos, & Jaric, 2018). The modelling of the F-V relationship from the
force and velocity data collected under more than two loads has been referred to as
multiple-point method (Zivkovic, Djuric, Cuk, Suzovic, & Jaric, 2017). However, since
the F-V relationship of isoinertial multi-joint tasks is known to be highly linear (Jaric,
2015), the same F-V relationship parameters could be obtained modelling the force and
velocity data recorded under only two different loading conditions (i.e., two-point
method) (Jaric, 2016). The potential advantages of the two-point method as compared
to the multiple-point method could be that it is both less time-consuming and less
prone to fatigue (Garcia-Ramos & Jaric, 2018; Jaric, 2016). However, the level of fatigue
induced by the routine testing procedure based on multiple loads when assessing the
F-V relationship during the SJ and CMJ exercises remains virtually unexplored.

The two-point method has been recently shown to provide the F-V relationship
parameters with a comparable reliability and high validity with respect to the multiplepoint method in various multi-joint movements (García-Ramos, Torrejón, MoralesArtacho, Pérez-Castilla, & Jaric, 2018; Pérez-Castilla, Jaric, Feriche, Padial, &
García-Ramos, 2018; Zivkovic et al., 2017). However, several methodological issues
need to be considered for an accurate application of the two-point method (GarciaRamos & Jaric, 2018). Those include the distance between the two experimental points,
the proximity of the experimental points to the force and velocity intercepts, and the
reliability of the individual points. Pérez-Castilla et al. (2018) found that the reliability
and concurrent validity of the F-V relationship parameters assessed during the bench
press throw exercise were higher using the two farthest experimental points, while the
data also suggested the need to have one point close to the force-intercept and another
point close to the velocity-intercept. García-Ramos et al. (2018) also suggested that the
F-V relationship tested during the leg cycle ergometer exercise should be obtained from
two distant loads, although the data of relatively high loads associated with a cadence
lower than 110 rpm should be avoided since the velocity values were meaningfully less
reliable than for lower loads, which in turn compromised the accuracy of the
F-V relationship. Specifically, as far as vertical jumps are concerned, only Zivkovic
et al. (2017) have supported the validity of the two-point method when the data of the
two most distant loads (0–32 kg) were considered during the CMJ exercise (r > 0.952).
Therefore, there is an apparent need of exploring the reliability and concurrent validity

SPORTS BIOMECHANICS 3

of the F-V relationship obtained from the two-point method in other jumping modalities, as well as of examining the effect of the two particular points selected for
determining the F-V relationship on its reliability and validity.

To address these research gaps, in the present study, we assessed on separate
occasions the F-V relationship during the SJ and CMJ exercises through five different

– – – – –
two-point methods (0 17 kg, 0 30 kg, 0 45 kg, 0 60 kg, and 0 75 kg) as well as
through the multiple-point method based on six loading conditions (0–17–30–45–
60–75 kg). In addition, the unloaded vertical jump height was assessed before and
after the testing procedure as a marker of neuromuscular fatigue (Sánchez-Medina &
González-Badillo, 2011). Specifically, we aimed (I) to compare the reliability and
concurrent validity of the F-V relationship parameters obtained from two-point methods differing in the distance between experimental points with respect to the multiplepoint method, and (II) to explore the effect of a routine vertical jump testing procedure
based on multiple loading conditions on unloaded jump height. We hypothesised that
(I) the reliability and concurrent validity of the F-V relationship parameters obtained

–
from the two-point method based on distant loads (i.e., 0 75 kg) would be high, while
the reliability and validity would progressively decrease when using more proximal
loads, and (II) a decrease in unloaded jump height would be observed following the
testing procedure. The expected findings would provide additional support for using
the two-point method during the routine testing of lower-body muscle function
through vertical jumps.

Methods

Participants

Totally, 18 physical active men volunteered to participate in this study (age:
22.3 ± 2.1 years, body mass 75.7 ± 7.0 kg, height 177.7 ± 6.3 cm; data presented as
mean ± standard deviation \[SD\]). Selection criteria included (I) having at least 1 year of
resistance training experience which included vertical jump exercises, (II) being able to
jump with a proper technique against the maximum tested load (75 kg or more), and
(III) being free of musculoskeletal pain or injury that could compromise testing.
Participants were also instructed to avoid any strenuous exercise over the course of
the study. All participants were informed of the study procedures and signed a written
informed consent type prior to initiating the study. The study protocol adhered to the
tenets of the Declaration of Helsinki and was approved by the University of Granada
Institutional Review Board.

Experimental design

A repeated-measures design was used to examine the reliability and concurrent validity
of the F-V relationship parameters obtained through two-point methods differing in the
distance between experimental points with respect to the multiple-point method during
two vertical jump exercises (SJ and CMJ). Participants undertook four testing sessions
(twice a week) over two consecutive weeks with at least 48 h of rest between them. In
a counterbalanced order, participants performed two sessions of the loaded free-weight

4 A. GARCÍA-RAMOS ET AL.

SJ exercise over one week and two sessions of the loaded free-weight CMJ exercise in
another week. The week prior to the first testing session was used to familiarise the
participants with the loaded SJ and CMJ exercises during two sessions separated by
48 h. All testing sessions were conducted in the laboratory under the direct supervision
of a skilled investigator, at the same time of day for each participant (± 1 h), and under
similar environmental conditions (~ 22 ºC and ~ 60 % humidity).

Testing procedures

Prior to the commencement of testing, participants performed a 10 min standardised
warm-up that included jogging, joint mobility and dynamic stretching, followed by six
unloaded jumps and three loaded jumps with a 17 kg load (mass of the unloaded
barbell) in the assessed exercise (SJ or CMJ). Once the warm-up was completed,
participants rested for 3 min and then they performed two jumps with a wooden
barbell of 0.5 kg. Thereafter, participants performed two vertical jumps against five
external loads (17, 30, 45, 60, and 75 kg). The five external loads were applied in
a randomised order. Finally, participants performed two more jumps with the 0.5 kg
barbell. Rest periods of 3–4 min between the trials of both the same and different loads
were implemented. Since a homogenous sample was recruited for this study, the same
absolute loads were used for all participants to simplify the testing procedure. The

’ –maximum load represented a 99.6 ± 8.4% of participants body mass \[range = 83.6

–
112.6%\] and it allowed a jump height of 8.1 ± 2.4 cm \[range = 4.3 13.6 cm\] and

–
8.7 ± 2.4 cm \[range = 5.8 13.2 cm\] during the SJ and CMJ exercises, respectively. The
trial with the highest maximum velocity at each loading condition was used for
modelling the F-V relationship since it is highly correlated with vertical jump height
(García-Ramos et al., 2015). The level of fatigue induced by the testing procedure was
quantified as the decrease in jump height considering the trial with the highest take-off
velocity at the beginning and at the end of each vertical jump test (Sánchez-Medina &
González-Badillo, 2011).

The SJ technique involved the participants standing with the knees and hips fully
extended, feet approximately shoulder-width apart and the barbell held across the
top of the shoulders and upper back. Participants then descended in a continuous
motion of 1.5 s until they reached approximately 90° of knee flexion (García-Ramos
et al., 2017). After maintaining this static position for 1.5 s, participants were
instructed to perform the concentric action with the instruction to jump as high
as possible (García-Ramos et al., 2017). If any countermovement was observed,
which was verbally restricted and carefully checked by its force-time curve, the
trial was repeated. The duration of eccentric and isometric phases was paced by
auditory signals, while the concentric phase was always performed at the maximum
intended velocity. For the CMJ technique, participants were only instructed to jump
as high as possible, but an experienced researcher ensured that participants met
a knee angle of approximately 90°. The trial was repeated if the depth of the
countermovement varied meaningfully from the 90º knee flexion. Trained spotters
were present to verbally encourage the participants throughout the test and lifting
belts were used to ensure safety.

SPORTS BIOMECHANICS 5

Measurement equipment and data analysis

Vertical jumps were performed on a force platform (Dinascan/IBV, Biomechanics
Institute of Valencia, Spain) that sampled the vertical ground reaction force (GRF)
data at a frequency of 1,000 Hz. Prior to each jump, the participants were weighed over
4 s with the external load laid on their shoulders to determine the total system weight
(sum of body weight and external weight). The start of the jump was defined as the first
time point when vertical GRF was 10 N above (SJ) or below (CMJ) the total system
weight (McLellan, Lovell, & Gass, 2011; Moir et al., 2004). For each jump, the system’s
centre-of-mass velocity was calculated through the trapezoidal rule (Linthorne, 2001).
Specifically, the net GRF was calculated as the amount of force exceeded the system
weight and then divided by the system mass to determine acceleration. Acceleration was
numerically integrated to provide instantaneous centre-of-mass velocity. Maximum
values of force and velocity at each loading condition as well as the jump height
reached during unloaded jumps were the dependent variables analysed. Jump height
was calculated following the take-off velocity procedure (Linthorne, 2001).

Maximum force and velocity data obtained under six different loads (0, 17, 30, 45, 60
and 75 kg) were first modelled by a least-squares linear regression model to determine
the F-V relationship parameters through the multiple-point method: F (V) = F0—aV,
where F0 represents the maximum force (i.e., force-intercept), V0 is the maximum
velocity (i.e., velocity-intercept) and a corresponds to the F-V relationship slope (F0/V0)
(Jaric, 2015; Vandewalle, Peres, Heller, Panel, & Monod, 1987). As a consequence of the
F-V relationship being highly linear, the maximum power (Pmax) was computed as Pmax

= F0•V0/4. The same F-V relationship parameters were calculated from five two-point
methods differing in the distance between experimental points: 0–17 kg, 0–30 kg,
0–45 kg, 0–60 kg and 0–75 kg (see Figure 1).

Only data from the first testing session of each jump type were used to examine the
concurrent validity of the selected two-point methods with respect to the multiple-point
method as well as to explore the effect of the vertical jump testing procedure based on
multiple loads on the unloaded jump height. The data obtained from both sessions of
each jump type were used for reliability analyses.

Statistical analyses

Data are presented as means and SD, while the Pearson’s correlation coefficients (r) are
presented through their median values and range. The reliability of the F-V relationship
parameters obtained from different methods was assessed through the coefficient of
variation (CV) and intra-class correlation coefficient (ICC; model 3.1). Acceptable
reliability was determined as a CV \< 10% and an ICC > 0.70 (Cormack, Newton,
McGuigan, & Doyle, 2008). Significant differences in reliability were identified when the
CV or ICC of the two-point method was above/below the 95% confidence interval of
the multiple-point method. Paired samples t-tests and Cohen’s d effect size (ES) were
used to compare the magnitude of the F-V relationship parameters between the five
two-point methods and the multiple-point method as well as the unloaded jump height
before and after the testing procedure. The criteria to interpret the magnitude of the ES
was as follows: negligible (\< 0.20), small (0.20–0.50), moderate (0.50–0.80) and large

6 A. GARCÍA-RAMOS ET AL.

#### **Squat jump**

#### 3500 2800 2100 1400 700 0 3500 2800 2100 1400 700

–
**Two-point (0** **17 kg)**

#### 0 2 4 6 8 **Countermovement jump**

–
**Two-point (0** **17 kg)**

#### 0 0 2 4 6 8 **Velocity (m/s)**

Figure 1. Force-velocity relationships obtained from the data averaged across the participants
modelled by the multiple-point method (solid regression line; all data points included) and selected
two-point methods (dashed regression lines; the two loads considered are indicated in parentheses)
during the squat jump (upper panel) and countermovement jump (lower panel) exercises. Mean
values are shown for the six loading conditions (0, 17, 30, 45, 60, and 75 kg), while the error bars
represent the standard deviation. Regression equations obtained from each individual method are
also indicated (r, Pearson’s correlation coefficient).

SPORTS BIOMECHANICS 7

(> 0.80) (Cohen, 1988). The r coefficients were used to assess the concurrent validity of
two-point methods respect to the multiple-point method and to explore the association
between the change in jump height and the magnitude of the F-V relationship parameters. The criteria to interpret the strength of the correlations were as follows: trivial
(\< 0.1), small (0.1–0.3), moderate (0.3–0.5), high (0.5–0.7), very high (0.7–0.9) or
practically perfect (> 0.9) (Hopkins, Marshall, Batterham, & Hanin, 2009). The agree
–
ment between the multiple- and two-point methods was quantified using Bland
Altman 95% limits of agreement (LoA) technique (bias ± (1.96 x SDdiff)). Statistical
significance was accepted at p \< 0.05 level, and confidence limits were set at 95%. The
reliability assessment was performed by means of a custom spreadsheet (Hopkins,
2000), while all other statistical analyses were performed using the software package
SPSS version 22.0 (SPSS Inc., Chicago, IL, USA).

Results

Reliability of the F-V relationship parameters

The reliability of the two-point methods tended to decrease with the use of more
proximal loads in both jumping modalities (Tables 1-2). An acceptable reliability (CV
\< 10% and ICC > 0.70) of the F-V relationship parameters for both jumping modalities
was only observed for the multiple-point method and the two-point method based on

–
the most distant loads (i.e., 0 75 kg). The only exception was the F-V slope during the

–
CMJ exercise: CV of 10.9% and 12.1% for multiple-point method and 0 75 two-point

Table 1. Magnitude and reliability of the force-velocity (F-V) relationship parameters obtained from
multiple-point method and the selected two-point methods during the squat jump exercise.

F-V method Parameter Session 1 Session 2 CV (95% CI) ICC (95% CI)

Multiple-point F0 3310 ± 326 3426 ± 370 3.61 (2.71, 5.41) 0.89 (0.74, 0.96)
V0 5.45 ± 0.53 5.39 ± 0.53 5.17 (3.88, 7.75) 0.74 (0.43, 0.90)
Pmax 4506 ± 566 4592 ± 503 3.39 (2.54, 5.08) 0.93 (0.82, 0.97)
F-V slope 614 ± 94 645 ± 120 8.62 (6.47, 12.9) 0.77 (0.48, 0.91)
Two-point F0 3314 ± 341 3439 ± 399 3.39 (2.54, 5.08) 0.92 (0.79, 0.97)

0–75 kg V0 5.49 ± 0.54 5.41 ± 0.51 5.34 (4.01, 8.01) 0.72 (0.39, 0.88)

Pmax 4537 ± 545 4625 ± 476 4.04 (3.03, 6.05) 0.88 (0.72, 0.95)
F-V slope 611 ± 102 645 ± 122 8.06 (6.05, 12.1) 0.82 (0.57, 0.93)
Two-point F0 3332 ± 348 3393 ± 381 5.36 (4.02, 8.04) 0.78 (0.50, 0.91)

0–60 kg V0 5.46 ± 0.57 5.50 ± 0.58 6.47 (4.86, 9.71) 0.65 (0.28, 0.85)

Pmax 4533 ± 530 4640 ± 482 3.72 (2.79, 5.57) 0.90 (0.75, 0.96)
F-V slope 619 ± 108 627 ± 123 11.6 (8.71, 17.41) 0.63 (0.25, 0.85)
Two-point F0 3243 ± 438 3382 ± 355 6.71 (5.04, 10.1)*0.71 (0.38, 0.88)*

0–75 kg

0–60 kg

Two-point F0 3243 ± 438 3382 ± 355 6.71 (5.04, 10.1)*0.71 (0.38, 0.88)*

0–45 kg V0 5.68 ± 0.60 5.52 ± 0.65 9.56 (7.17, 14.3)*0.29 (−0.19, 0.66)*

Pmax 4568 ± 524 4636 ± 484 4.35 (3.26, 6.52) 0.86 (0.66, 0.94)
F-V slope 582 ± 127 624 ± 110 15.4 (11.6, 23.12)*0.41 (−0.06, 0.73)*
Two-point F0 3258 ± 533 3291 ± 567 8.44 (6.34, 12.7)\* 0.77 (0.48, 0.91)

0–45 kg

Two-point F0 3258 ± 533 3291 ± 567 8.44 (6.34, 12.7)\* 0.77 (0.48, 0.91)

0–30 kg V0 5.79 ± 0.98 5.85 ± 0.91 11.0 (8.24, 16.5)\* 0.57 (0.15, 0.81)

Pmax 4628 ± 591 4717 ± 453 4.92 (3.69, 7.37) 0.83 (0.60, 0.93)
F-V slope 589 ± 178 587 ± 183 19.4 (14.6, 29.1)*0.62 (0.24, 0.84)
Two-point F0 4228 ± 4497 3168 ± 805 81.9 (61.5, 122.8)* 0.13 (−0.35, 0.55)\*

0–30 kg

0–17 kg

F0 4228 ± 4497 3168 ± 805 81.9 (61.5, 122.8)*0.13 (−0.35, 0.55)*
V0 6.40 ± 2.10 7.60 ± 5.16 45.5 (34.1, 68.2)*0.37 (−0.11, 0.70)*
Pmax 5415 ± 2084 5383 ± 1925 37.5 (28.1, 56.1)*−0.02 (−0.47, 0.44)*
F-V slope 1027 ± 2008 541 ± 285 173.9 (130.5, 260.7)*0.10 (−0.37, 0.53)*

F0, maximum force (N); V0, maximum velocity (m/s); Pmax, maximum power (W); F-V slope, force-velocity slope (N· s/m);

CV, coefficient of variation; 95% CI, 95% confidence interval; ICC, intraclass correlation coefficient; \*, below (ICC) or
above (CV) 95% CI observed from the multiple-point method.

8 A. GARCÍA-RAMOS ET AL.

Table 2. Magnitude and reliability of the force-velocity (F-V) relationship parameters obtained from
multiple-point method and the selected two-point methods during the countermovement jump
exercise.

F-V method Parameter Session 1 Session 2 CV (95% CI) ICC (95% CI)

Multiple-point F0 3253 ± 343 3219 ± 289 3.91 (2.94, 5.87) 0.86 (0.66, 0.94)
V0 5.84 ± 1.11 5.96 ± 1.07 6.62 (4.96, 9.92) 0.72 (0.72, 0.96)
Pmax 4684 ± 563 4743 ± 547 3.31 (2.48, 4.96) 0.82 (0.82, 0.97)
F-V slope 579 ± 135 558 ± 114 10.9 (8.14, 16.3) 0.78 (0.50, 0.91)
Two-point F0 3268 ± 375 3280 ± 327 4.26 (3.20, 6.39) 0.86 (0.66, 0.94)

0–75 kg V0 5.95 ± 1.05 5.91 ± 1.01 8.28 (6.21, 12.4) 0.79 (0.53, 0.92)

Pmax 4799 ± 552 4795 ± 540 4.82 (3.62, 7.23) 0.84 (0.62, 0.94)
F-V slope 570 ± 137 572 ± 117 12.1 (9.08, 18.2) 0.73 (0.41, 0.89)
Two-point F0 3213 ± 322 3144 ± 249 5.16 (3,87, 7.74) 0.70 (0.36, 0.88)

0–60 kg V0 6.07 ± 1.07 6.24 ± 1.19 10.3 (7.70, 15.4)*0.71 (0.38, 0.88)*

Pmax 4815 ± 561 4855 ± 627 5.56 (4.18, 8.34)*0.82 (0.57, 0.93)*
F-V slope 550 ± 134 522 ± 108 14.9 (11.2, 22.4) 0.59 (0.19, 0.83)
Two-point F0 3068 ± 367 3089 ± 247 7.53 (5.65, 11.3)*0.48 (0.03, 0.77)*

0–45 kg V0 6.52 ± 1.25 6.58 ± 1.29 14.6 (11.0, 21.9)*0.46 (0.00, 0.76)*

Pmax 4926 ± 658 4940 ± 689 7.45 (5.59, 11.2)*0.73 (0.40, 0.89)*
F-V slope 495 ± 142 482 ± 112 21.2 (15.9, 31.8)*0.36 (−0.11, 0.70)*
Two-point F0 2926 ± 376 2979 ± 380 9.98 (7.39, 14.8)*0.43 (−0.03, 0.74)*

0–30 kg V0 7.08 ± 1.61 7.45 ± 3.09 30.0 (22.5, 45.0)*0.23 (−0.25, 0.62)*

Pmax 5080 ± 814 5308 ± 1310 17.2 (12.9, 25.8)*0.35 (−0.13, 0.69)*
F-V slope 442 ± 151 459 ± 169.1 28.5 (21.4, 42.7)*0.38, (−0.09, 0.71)*
Two-point F0 2693 ± 598.2 3034 ± 702 21.0 (15.8, 31.5)*0.16 (−0.32, 0.57)*

0–75 kg

0–60 kg

0–45 kg

0–30 kg

0–17 kg

F0 2693 ± 598.2 3034 ± 702 21.0 (15.8, 31.5)*0.16 (−0.32, 0.57)*
V0 13.46 ± 18.31 9.36 ± 8.07 103.8 (77.9, 155.6)*0.32 (−0.16, 0.68)*
Pmax 7823 ± 8103 6218 ± 3513 75.2 (56.4, 112.7)*0.30 (−0.18, 0.67)*
F-V slope 352 ± 244 481 ± 289 59.7 (44.8, 89.5)*0.14 (−0.33, 0.56)*

F0, maximum force (N); V0, maximum velocity (m/s); Pmax, maximum power (W); F-V slope, force-velocity slope (N· s/m);

CV, coefficient of variation; 95% CI, 95% confidence interval; ICC, intra-class correlation coefficient; \*, below (ICC) or
above (CV) 95% CI observed from the multiple-point method.

method, respectively. No meaningful differences in reliability were observed between
the multiple-point and the two most distant two-point methods (i.e., 0–60 and 0–75 kg)
for the SJ exercise (Table 1) as well as between the multiple-point method and the 0–75
two-point method for the CMJ exercise (Table 2).

Concurrent validity of the F-V relationship parameters

The F-V relationship recorded from the multiple-point method was highly linear when
obtained either from the data averaged across the participants (r ≥ 0.99) or from the
individual force and velocity data (r = 0.99 \[0.97, 1.00\] for SJ; r = 0.98 \[0.95, 0.99\]) for
CMJ). As a consequence of the high linearity reported, the F-V relationships obtained
from the two-point methods (particularly the 0–60 and 0–75 two-point methods)
considerably overlapped with the F-V relationship obtained from the multiple-point
method (Figure 1).

The concurrent validity of the F-V relationship parameters obtained from the two
–
point methods tended to decrease with the use of more proximal loads (0 17 kg
\< 0–30 kg \< 0–45 kg \< 0–60 kg = 0–75 kg) (Table 3). Only the two more distant two
– –
point methods (i.e., 0 60 kg and 0 75 kg) provided practically perfect correlations
(0.91 ≤ r ≤ 0.98) as well as small differences in their magnitudes (all ES ≤ 0.23) with

–
respect to the multiple-point method. The LoA was also narrower for the 0 60 kg and
0–75 kg two-point methods. These results were consistent across the SJ and CMJ
exercises.

SPORTS BIOMECHANICS 9

10 A. GARCÍA-RAMOS ET AL.

Change in jump height after the testing procedure

Significant decreases in unloaded jump height were observed after the testing procedures conducted with both the SJ and CMJ exercises (Figure 2). No significant correlations were observed between the change in unloaded jump height and the magnitude of
the F-V relationship parameters with the only exception of V0 during the SJ testing
procedure (p = 0.022, r = 0.54) (Figure 3).

Discussion and implications

The present study was designed to explore (I) the reliability and concurrent validity of
the F-V relationship parameters obtained from two-point methods differing in the
distance between experimental points with respect to the multiple-point method during
two jumping modalities (SJ and CMJ) as well as (II) to examine the effect of a vertical
jump testing procedure based on multiple loads on unloaded jump height. Supporting
the first hypothesis, the two-point method obtained from the two farthest loads (i.e.,
0–75 kg) revealed a comparable reliability and high concurrent validity with respect to
the multiple-point method. However, both the reliability and concurrent validity of the

12

8

4

0

-4

-8

-12

**SJ** **CMJ**

Figure 2. Individual changes in unloaded jump height after the testing procedure based on multiple
loads during the squat jump (SJ) and countermovement jump (CMJ) exercises. The solid lines show
the median difference. p, p-value (paired samples t-tests); ES, Cohen’s d effect size (\[jump height
pre—jump height post\]/SD both); %Δ, percentage differences (\[jump height pre—jump height post\]/
jump height post x 100).

12

8

4

0

SPORTS BIOMECHANICS 11

**SJ**

-4

-8

-12

-16

2000 3000 4000 5000

**Maximum force (N)**

12

8

4

0

-4

-8

-12

-16

2.0 4.0 6.0 8.0 10.0 12.0

**Maximum velocity (m/s)**

12

8

4

0

-4

-8

-12

-16

2500 3500 4500 5500 6500 7500

**Maximum power (W)**

Figure 3. Relationship between the changes in unloaded jump height and maximum force (upper
panel), maximum velocity (middle panel) and maximum power (lower panel) during the squat jump
(SJ; straight line and filled dots) and countermovement jump (CMJ; dashed line and empty dots)
exercises. r, Pearson’s correlation coefficient; p, p-value (significant association; p \< 0.05).

12 A. GARCÍA-RAMOS ET AL.

F-V relationship parameters tended to gradually decrease with the use of more proximal loads. The second hypothesis was also confirmed since the unloaded jump height
was significantly reduced after the SJ and CMJ testing procedures. Collectively, these
results support the use of the two-point method based on distant loads for testing the
lower-body muscle function through vertical jumps.

The basic prerequisite for the application of the two-point method is that the
F-V relationship should be strong and, as a consequence, highly linear (Jaric, 2016). In
agreement with previous studies conducted with vertical jumps, the F-V relationship modelled from the force and velocity data recorded under six loading conditions (0–17–30–45–
60–75 kg) was highly linear (r > 0.98) for both SJ and CMJ (Cuk et al., 2014; Feeney et al.,
2016; García-Ramos et al., 2017; Samozino et al., 2014). Due to the expected high linearity of
the F-V relationship, we hypothesised that the F-V relationship parameters obtained from the

–
two-point method, especially when based on the two most distant loads (i.e., 0 75 kg), would
be reliable and valid when compared to the multiple-point method. Our results are in line
with previous studies showing that the two-point method based on the two farthest data
points provides the F-V relationship parameters with a comparable reliability and high
validity respect to the multiple-point method in various multi-joint movements, such as in
cycling, bench press, prone bench pull and others (García-Ramos et al., 2018; Pérez-Castilla
et al., 2018; Zivkovic et al., 2017). However, the results also confirm that the selection of the
two particular loads for the application of the two-point method regarding both their
magnitude and the distance between them meaningfully influences both the reliability and
validity of the F-V relationship parameters (Garcia-Ramos & Jaric, 2018).

To our knowledge, only two previous studies have examined the effect of the distance
between experimental points on the reliability and concurrent validity of the
F-V relationship parameters obtained from the two-point method. Pérez-Castilla et al.
(2018) found that the reliability and concurrent validity of the F-V relationship parameters
during the bench press throw exercise tended to decrease with the proximity between
experimental points (40–50% \< 30–60% \< 20–70% of one-repetition maximum). Similarly,
García-Ramos et al. (2018) showed that two distant loads should be considered in the leg
cycle ergometer exercise to maximise the reliability of the F-V relationship parameters, but
avoiding very high resistances that provide cadences lower than 110 rpm since their lower
reliability could compromise the reliability of the F-V relationship. Our results are in line
with the previous findings, since both the reliability and concurrent validity of the
F-V relationship parameters tended to decrease with the proximity between experimental
points. In this regard, two distant loads should be considered to maximise the reliability of
the F-V relationship during the two jumping modalities tested (SJ and CMJ). However,
since the reliability of the jump height is remarkably lower when tested against heavy
external loads that do not allow a jump height higher than 10 cm (Pérez-Castilla &
García-Ramos, 2018; Perez-Castilla, McMahon, Comfort, & Garcia-Ramos, 2017), we
recommend that the two-point method during vertical jumps is based on an unloaded
jump (minimum possible loading condition) and a heavy load that allows a jump height
slightly higher than 10 cm. A load associated with a jump height of 10 cm would provide an
experimental point close to F0, while heavier loads could compromise the reliability of the
mechanical outputs (i.e., values of force, velocity or jump height) and in turn the accuracy
of the modelled F-V relationship. It should also be noted that the use of two proximal loads
(e.g., 0–17 kg, 0–30 kg and 0–45 kg) leads to inconsistent results and significant bias.

SPORTS BIOMECHANICS 13

Finally, since the routine vertical jump testing procedure used to determine the
F-V relationship is based on multiple loading conditions (e.g., six loads in the present
study), we hypothesised that this procedure would induce fatigue. Supporting this
hypothesis, a significant and meaningful unloaded jump height loss was observed

–
after each testing procedure despite providing long rest intervals (3 4 min) between
the different trials. Although the magnitude of the decrement in jump height was
comparable for the SJ and CMJ testing procedures, the variability in the change of
jump height was higher during the SJ testing procedure. Future studies should elucidate
why the variability is higher during the SJ exercise since in the present study we
observed comparable reliability of unloaded jump height for both jump types
(CV = 6.24% and 4.70% for SJ and CMJ, respectively). In general, the magnitudes of
the F-V relationship parameters were not related to the change in the jump height after
the testing procedure. The only significant association observed between the values of
V0 and the change in jump height after the testing procedure conducted with the SJ
exercise requires further investigation. Thus, the routine procedure used to determine
the F-V relationship based on the application of multiple loading conditions could
cause a fatigue-associated reduction in the maximal mechanical capacities of the
muscles (i.e., F0, V0 and Pmax) assessed through the F-V relationship. These effects
are expected independently from whether the loads are applied in an incremental or
randomised sequence (Cuk et al., 2014; Feeney et al., 2016; Giroux, Rabita, Chollet, &
Guilhem, 2015). Particularly, the expected progressive development of fatigue during
the test would mainly underestimate the maximal force capacity (F0) when the loads are
applied in an incremental order. The outcomes of the F-V relationship would be
randomly affected when the loads are applied in a randomised order (i.e., when the
heavy loads are applied at the end of the test is expected to mainly affect F0, while if the
light loads are applied at the end of the test is expected to affect V0). Therefore, the twopoint method could be considered as a viable alternative to the multiple-point method
during vertical jump testing procedures that markedly reduces both the complexity of
the testing protocol and the associated fatigue, while still providing reliable and valid

outcomes.

It should be acknowledged as a limitation of the present study that the reliability and
concurrent validity of the two-point methods were explored from a testing procedure
based on multiple loads. To date, only one study has confirmed the feasibility of the twopoint method applied in field conditions (i.e., when only two loads are applied in the
testing protocol) during the leg cycle ergometer exercise (García-Ramos et al., 2018).
Therefore, more research is needed to develop the testing procedure based on only two
loads during different exercises. Although in the present study we only presented the
F-V relationships obtained from the maximum values of force and velocity, it should be
noted that the main findings of the present study (i.e., comparable reliability and high
concurrent validity of the two-point methods based on distant loads) are also applicable
when the mean values of force and velocity are used to determine the F-V relationships.
However, we decided to present the maximum values due to the lower reliability of mean
velocity compared with maximum velocity during the SJ, which is probably caused because
the threshold used to identify the start of the concentric phase (10 N above system weight)
was not conservative enough to accurately assess mean velocity during the loaded SJ.

14 A. GARCÍA-RAMOS ET AL.

Conclusions

The two-point method based on distant loads is a reliable and valid procedure that could
be developed for testing the maximal force, velocity and power producing capacities of leg
muscles through vertical jumps. Specifically, we recommend that the two-point method
during traditional vertical jumps should be based on an unloaded jump (minimum
possible loading condition) and a heavy load that allows reaching a jump height of

– ’
about 10 cm (it generally represents a 75 100% of participants body mass). It should
also be taken in mind that the routine testing procedure of the F-V relationship based on
multiple loading conditions could underestimate the outcomes of the F-V relationship due
to the progressive fatigue induced by the testing procedure. Therefore, the two-point
method based on distant loads could be a quicker and less prone fatigue alternative for
testing the lower-body muscle function during the SJ and CMJ exercises.

Acknowledgments

The authors thank all the participants who selflessly participated in the study.

Disclosure statement

No potential conflict of interest was reported by the authors.

Funding

This study was supported by the University of Granada under a postdoctoral grant \[perfeccionamiento de doctors\] awarded to AGR and by the Spanish Ministry of Education, Culture and
Sport under a pre-doctoral grant \[FPU15/03649\] awarded to APC.

ORCID

Amador García-Ramos <http://orcid.org/0000-0003-0608-8755>
Alejandro Pérez-Castilla <http://orcid.org/0000-0001-5535-2087>
Slobodan Jaric <http://orcid.org/0000-0002-0919-0483>

References

Baker, D. (1996). Improving vertical jump performance through general, special, and specific

strength training: A brief review. Journal of Strength & Conditioning Research, 10, 131–136.
[doi:10.1519/00124278-199605000-00015](https://doi.org/10.1519/00124278-199605000-00015)
Bobbert, M. F., Gerritsen, K. G., Litjens, M. C., & Van Soest, A. J. (1996). Why is counter
movement jump height greater than squat jump height? Medicine and Science in Sports and
[Exercise, 28, 1402–1412. doi:10.1097/00005768-199611000-00009](https://doi.org/10.1097/00005768-199611000-00009)
Cohen, J. (1988). Statistical power analysis for the behavioral sciences (2nd ed. Chapter 8,

286–288). Hillsdale, NJ: Lawrance Erlbaum Associates.
Cormack, S. J., Newton, R. U., McGuigan, M. R., & Doyle, T. L. A. (2008). Reliability of measures

obtained during single and repeated countermovement jumps. International Journal of Sports
[Physiology and Performance, 3, 131–144. doi:10.1123/ijspp.3.2.131](https://doi.org/10.1123/ijspp.3.2.131)

SPORTS BIOMECHANICS 15

Cormie, P., McBride, J. M., & McCaulley, G. O. (2008). Power-time, force-time, and

velocity-time curve analysis during the jump squat: Impact of load. Journal of Applied
[Biomechanics, 24, 112–120. doi:10.1123/jab.24.2.112](https://doi.org/10.1123/jab.24.2.112)
Cuk, I., Markovic, M., Nedeljkovic, A., Ugarkovic, D., Kukolj, M., & Jaric, S. (2014). Force
velocity relationship of leg extensors obtained from loaded and unloaded vertical jumps.
[European Journal of Applied Physiology, 114, 1703–1714. doi:10.1007/s00421-014-2985-8](https://doi.org/10.1007/s00421-014-2985-8)
Feeney, D., Stanhope, S. J., Kaminski, T. W., Machi, A., & Jaric, S. (2016). Loaded vertical

jumping: Force-velocity relationship, work, and power. Journal of Applied Biomechanics, 32,
[120–127. doi:10.1123/jab.2015-0136](https://doi.org/10.1123/jab.2015-0136)
García-Ramos, A., Feriche, B., Pérez-Castilla, A., Padial, P., & Jaric, S. (2017). Assessment of leg

muscles mechanical capacities: Which jump, loading, and variable type provide the most
reliable outcomes? European Journal of Sport Science, 17, 690–698. [doi:10.1080/](https://doi.org/10.1080/17461391.2017.1304999)
[17461391.2017.1304999](https://doi.org/10.1080/17461391.2017.1304999)
Garcia-Ramos, A., & Jaric, S. (2018). Two-point method: A quick and fatigue-free procedure for

assessment of muscle mechanical capacities and the one-repetition maximum. Strength and
[Conditioning Journal, 40, 54–56. doi:10.1519/SSC.0000000000000359](https://doi.org/10.1519/SSC.0000000000000359)
García-Ramos, A., Štirn, I., Padial, P., Argüelles-Cienfuegos, J., De la Fuente, B., Strojnik, V., &

Feriche, B. (2015). Predicting vertical jump height from bar velocity. Journal of Sports Science
and Medicine, 14, (2):256–262. PMID:25983572
García-Ramos, A., Torrejón, A., Morales-Artacho, A. J., Pérez-Castilla, A., & Jaric, S. (2018).

Optimal resistive forces for maximizing the reliability of leg muscles’ capacities tested on
[a cycle ergometer. Journal of Applied Biomechanics, 34, 47–52. doi:10.1123/jab.2017-0056](https://doi.org/10.1123/jab.2017-0056)
García-Ramos, A., Zivkovic, M., Djuric, S., Majstorovic, N., Manovski, K., & Jaric, S. (2018).

Assessment of the two-point method applied in field conditions for routine testing of muscle
mechanical capacities in a leg cycle ergometer. European Journal of Applied Physiology, 118,
[1877–1884. doi:10.1007/s00421-017-3750-6](https://doi.org/10.1007/s00421-017-3750-6)
Giroux, C., Rabita, G., Chollet, D., & Guilhem, G. (2015). What is the best method for assessing

lower limb force-velocity relationship? International Journal of Sports Medicine, 36, 143–149.
[doi:10.1055/s-0034-1385886](https://doi.org/10.1055/s-0034-1385886)
Hansen, K. T., Cronin, J. B., Pickering, S. L., & Newton, M. J. (2011). Does cluster loading

enhance lower body power development in preseason preparation of elite rugby union
[players? Journal of Strength and Conditioning Research, 25, 2118–2126. doi:10.1519/](https://doi.org/10.1519/JSC.0b013e318220b6a3)
[JSC.0b013e318220b6a3](https://doi.org/10.1519/JSC.0b013e318220b6a3)
Hopkins, W. (2000). Calculations for reliability (Excel spreedsheet). A new view of statistics.

[Retrieved October 1, 2018, from http://www.sportsci.org/resource/stats/relycalc.html#excel](http://www.sportsci.org/resource/stats/relycalc.html%23excel)
Hopkins, W. G., sMarshall, S. W., Batterham, A. M., & Hanin, J. (2009). Progressive statistics for

studies in sports medicine and exercise science. Medicine and Science in Sports and Exercise,
[41, 3–13. doi:10.1249/MSS.0b013e31818cb278](https://doi.org/10.1249/MSS.0b013e31818cb278)
Iglesias-Soler, E., Farinas, J., Mayo, X., Santos, L., & Jaric, S. (2018). Comparison of different

regression models to fit the force-velocity relationship of a knee extension exercise. Sports
[Biomechanics. Advance of publication. doi:10.1080/14763141.2018.1442873](https://doi.org/10.1080/14763141.2018.1442873)
Jaric, S. (2015). Force-velocity relationship of muscles performing multi-joint maximum perfor
[mance tasks. International Journal of Sports Medicine, 36, 699–704. doi:10.1055/s-00000028](https://doi.org/10.1055/s-00000028)
Jaric, S. (2016). Two-load method for distinguishing between muscle force, velocity, and

[power-producing capacities. Sports Medicine, 46, 1585–1589. doi:10.1007/s40279-016-0531-z](https://doi.org/10.1007/s40279-016-0531-z)
Linthorne, N. P. (2001). Analysis of standing vertical jumps using a force platform. American

[Journal of Physics, 69, 11. doi:10.1119/1.1397460](https://doi.org/10.1119/1.1397460)
Markovic, G., Dizdar, D., Jukic, I., & Cardinale, M. (2004). Reliability and factorial validity of

squat and countermovement jump tests. Journal of Strength and Conditioning Research, 18,
[551–555. doi:10.1519/1533-4287(2004)18\<551:RAFVOS>2.0.CO;2](https://doi.org/10.1519/1533-4287)
McBride, J. M., Haines, T. L., & Kirby, T. J. (2011). Effect of loading on peak power of the bar,

body, and system during power cleans, squats, and jump squats. Journal of Sports Sciences, 29,
[1215–1221. doi:10.1080/02640414.2011.587444](https://doi.org/10.1080/02640414.2011.587444)

16 A. GARCÍA-RAMOS ET AL.

McLellan, C. P., Lovell, D. I., & Gass, G. C. (2011). The role of rate of force development on

vertical jump performance. Journal of Strength and Conditioning Research, 25, 379–385.
[doi:10.1519/JSC.0b013e3181be305c](https://doi.org/10.1519/JSC.0b013e3181be305c)
Moir, G., Button, C., Glaister, M., & Stone, M. H. (2004). Influence of familiarization on the

reliability of vertical jump and acceleration sprinting performance in physically active men.
[Journal of Strength and Conditioning Research, 18, 276–280. doi:10.1519/R-13093.1](https://doi.org/10.1519/R-13093.1)
Pérez-Castilla, A., & García-Ramos, A. (2018). Evaluation of the most reliable procedure of

determining jump height during the loaded countermovement jump exercise: Take-off velo[city vs. flight time. Journal of Strength and Conditioning Research, 32, 2025–2030. doi:10.1519/](https://doi.org/10.1519/JSC.0000000000002583)
[JSC.0000000000002583](https://doi.org/10.1519/JSC.0000000000002583)
Pérez-Castilla, A., Jaric, S., Feriche, B., Padial, P., & García-Ramos, A. (2018). Evaluation of

muscle mechanical capacities through the two-load method: Optimization of the load
[selection. Journal of Strength and Conditioning Research, 32, 1245–1253. doi:10.1519/](https://doi.org/10.1519/JSC.0000000000001969)
[JSC.0000000000001969](https://doi.org/10.1519/JSC.0000000000001969)
Perez-Castilla, A., McMahon, J. J., Comfort, P., & Garcia-Ramos, A. (2017). Assessment of

loaded squat jump height with a free-weight barbell and Smith machine: Comparison of the
take-off velocity and flight time procedures. Journal of Strength and Conditioning Research.
[Advance of publication. doi:10.1519/JSC.0000000000002166](https://doi.org/10.1519/JSC.0000000000002166)
Runge, M., Rittweger, J., Russo, C. R., Schiessl, H., & Felsenberg, D. (2004). Is muscle power

output a key factor in the age-related decline in physical performance? A comparison of
muscle cross section, chair-rising test and jumping power. Clinical Physiology and Functional
[Imaging, 24, 335–340. doi:10.1111/cpf.2004.24.issue-6](https://doi.org/10.1111/cpf.2004.24.issue-6)
Samozino, P., Edouard, P., Sangnier, S., Brughelli, M., Gimenez, P., & Morin, J. B. (2014). Force
velocity profile: Imbalance determination and effect on lower limb ballistic performance.
[International Journal of Sports Medicine, 35, 505–510. doi:10.1055/s-0033-1354382](https://doi.org/10.1055/s-0033-1354382)
Sánchez-Medina, L., & González-Badillo, J. J. (2011). Velocity loss as an indicator of neuromus
cular fatigue during resistance training. Medicine & Science in Sports & Exercise, 43,
[1725–1734. doi:10.1249/MSS.0b013e318213f880](https://doi.org/10.1249/MSS.0b013e318213f880)
Vandewalle, H., Peres, G., Heller, J., Panel, J., & Monod, H. (1987). Force-velocity relationship

and maximal power on a cycle ergometer. Correlation with the height of a vertical jump.
European Journal of Applied Physiology and Occupational Physiology, 56, 650–656.
[doi:10.1007/BF00424805](https://doi.org/10.1007/BF00424805)
Zivkovic, M. Z., Djuric, S., Cuk, I., Suzovic, D., & Jaric, S. (2017). A simple method for

assessment of muscle force, velocity, and power producing capacities from functional move[ment tasks. Journal of Sports Sciences, 35, 1287–1293. doi:10.1080/02640414.2016.1221521](https://doi.org/10.1080/02640414.2016.1221521)
